pub struct AttrId {
id: u32,
}Expand description
This is an index of an attribute that always points to the item tree attributes.
Outer attributes are counted first, then inner attributes. This does not support out-of-line modules, which may have attributes spread across 2 files!
Fields
id: u32Implementations
Sourceimpl AttrId
impl AttrId
pub fn from_item_tree_index(id: u32) -> Self
pub fn item_tree_index(self) -> u32
Sourcepub fn find_attr_range<N: HasAttrs>(
self,
db: &dyn SourceDatabase,
krate: Crate,
owner: AstId<N>,
) -> (Attr, Meta)
pub fn find_attr_range<N: HasAttrs>( self, db: &dyn SourceDatabase, krate: Crate, owner: AstId<N>, ) -> (Attr, Meta)
Returns the containing ast::Attr (note that it may contain other attributes as well due
to cfg_attr) and its [ast::Meta].
Sourcepub fn find_attr_range_with_source(
self,
db: &dyn SourceDatabase,
krate: Crate,
owner: &dyn HasAttrs,
) -> (Attr, Meta)
pub fn find_attr_range_with_source( self, db: &dyn SourceDatabase, krate: Crate, owner: &dyn HasAttrs, ) -> (Attr, Meta)
Returns the containing ast::Attr (note that it may contain other attributes as well due
to cfg_attr) and its [ast::Meta].
Assumes that the attribute syntax node was present in the original file (not speculatively expanded macro output).
Sourcepub(crate) fn find_attr_range_with_source_opt(
self,
db: &dyn SourceDatabase,
krate: Crate,
owner: &dyn HasAttrs,
) -> Option<(Attr, Meta)>
pub(crate) fn find_attr_range_with_source_opt( self, db: &dyn SourceDatabase, krate: Crate, owner: &dyn HasAttrs, ) -> Option<(Attr, Meta)>
Returns the containing ast::Attr (note that it may contain other attributes as well due
to cfg_attr) and its [ast::Meta].
pub fn find_derive_range( self, db: &dyn SourceDatabase, krate: Crate, owner: AstId<Adt>, derive_index: u32, ) -> TextRange